@@ -9,7 +9,7 @@ class DataPackageServerConstants:
        fullPath = path.absolute()
        fullPath = fullPath.as_posix()
        self.DATABASE = fullPath
-       self.HTTPPORT = '8080'
+       self.APIPORT = '8080'
        self.DEFAULTRETURN = 'other'
        self.GET = 'GET'
        self.PUT = 'PUT'
@@ -18,6 +18,6 @@ class DataPackageServerConstants:
        self.HTTPDEBUG = False
        self.HTTPMETHODS = ['POST', 'GET', 'PUT']
     
-       self.versionInfo = 'FreeTAKServer-0.8.4.6-Beta'
+       self.versionInfo = 'FreeTAKServer-0.8.20-Beta'
        self.NodeID = 'Public-FTS'
        self.VERSIONJSON = '{"version":"2","type":"ServerConfig", "data":{"version": "%s", "api": "2","hostname":"%s"}, "nodeId":"%s"}' % (self.versionInfo, "0.0.0.0" ,self.NodeID)
